/* display.c generated by valac 0.17.2.20-113d, the Vala compiler
 * generated from display.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PAIR (boxes_pair_get_type ())
#define BOXES_PAIR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PAIR, BoxesPair))
#define BOXES_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PAIR, BoxesPairClass))
#define BOXES_IS_PAIR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PAIR))
#define BOXES_IS_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PAIR))
#define BOXES_PAIR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PAIR, BoxesPairClass))

typedef struct _BoxesPair BoxesPair;
typedef struct _BoxesPairClass BoxesPairClass;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesDisplayPrivate BoxesDisplayPrivate;

#define BOXES_TYPE_DISPLAY_CONFIG (boxes_display_config_get_type ())
#define BOXES_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfig))
#define BOXES_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))
#define BOXES_IS_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_IS_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_DISPLAY_CONFIG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))

typedef struct _BoxesDisplayConfig BoxesDisplayConfig;
typedef struct _BoxesDisplayConfigClass BoxesDisplayConfigClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_DISPLAY_TYPE_SAVED_PROPERTY (boxes_display_saved_property_get_type ())
typedef struct _BoxesDisplaySavedProperty BoxesDisplaySavedProperty;
typedef struct _Block7Data Block7Data;

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

typedef enum  {
	BOXES_ERROR_INVALID,
	BOXES_ERROR_COMMAND_FAILED
} BoxesError;
#define BOXES_ERROR boxes_error_quark ()
struct _BoxesDisplay {
	GObject parent_instance;
	BoxesDisplayPrivate * priv;
	GHashTable* displays;
};

struct _BoxesDisplayClass {
	GObjectClass parent_class;
	GtkWidget* (*get_display) (BoxesDisplay* self, gint n, GError** error);
	GdkPixbuf* (*get_pixbuf) (BoxesDisplay* self, gint n, GError** error);
	void (*set_enable_inputs) (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
	void (*connect_it) (BoxesDisplay* self);
	void (*disconnect_it) (BoxesDisplay* self);
	GList* (*get_properties) (BoxesDisplay* self, BoxesPropertiesPage page);
	const gchar* (*get_protocol) (BoxesDisplay* self);
	gchar* (*get_uri) (BoxesDisplay* self);
};

struct _BoxesDisplayPrivate {
	gboolean _can_grab_mouse;
	gboolean _mouse_grabbed;
	gboolean _need_password;
	gboolean _need_username;
	gchar* _password;
	gchar* _username;
	BoxesDisplayConfig* _config;
};

struct _BoxesDisplaySavedProperty {
	gchar* name;
	GValue default_value;
};

struct _Block7Data {
	int _ref_count_;
	BoxesDisplay * self;
	GObject* display;
	BoxesDisplaySavedProperty* saved_properties;
	gint saved_properties_length1;
};


static gpointer boxes_display_parent_class = NULL;
static BoxesIPropertiesProviderIface* boxes_display_boxes_iproperties_provider_parent_iface = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
gpointer boxes_pair_ref (gpointer instance);
void boxes_pair_unref (gpointer instance);
GParamSpec* boxes_param_spec_pair (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_pair (GValue* value, gpointer v_object);
void boxes_value_take_pair (GValue* value, gpointer v_object);
gpointer boxes_value_get_pair (const GValue* value);
GType boxes_pair_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
GQuark boxes_error_quark (void);
GType boxes_display_config_get_type (void) G_GNUC_CONST;
#define BOXES_DISPLAY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DISPLAY, BoxesDisplayPrivate))
enum  {
	BOXES_DISPLAY_DUMMY_PROPERTY,
	BOXES_DISPLAY_PROTOCOL,
	BOXES_DISPLAY_URI,
	BOXES_DISPLAY_CAN_GRAB_MOUSE,
	BOXES_DISPLAY_MOUSE_GRABBED,
	BOXES_DISPLAY_NEED_PASSWORD,
	BOXES_DISPLAY_NEED_USERNAME,
	BOXES_DISPLAY_PASSWORD,
	BOXES_DISPLAY_USERNAME,
	BOXES_DISPLAY_CONFIG
};
GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n, GError** error);
static GtkWidget* boxes_display_real_get_display (BoxesDisplay* self, gint n, GError** error);
GdkPixbuf* boxes_display_get_pixbuf (BoxesDisplay* self, gint n, GError** error);
static GdkPixbuf* boxes_display_real_get_pixbuf (BoxesDisplay* self, gint n, GError** error);
void boxes_display_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
static void boxes_display_real_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
void boxes_display_connect_it (BoxesDisplay* self);
static void boxes_display_real_connect_it (BoxesDisplay* self);
void boxes_display_disconnect_it (BoxesDisplay* self);
static void boxes_display_real_disconnect_it (BoxesDisplay* self);
GList* boxes_display_get_properties (BoxesDisplay* self, BoxesPropertiesPage page);
static GList* boxes_display_real_get_properties (BoxesDisplay* self, BoxesPropertiesPage page);
GType boxes_display_saved_property_get_type (void) G_GNUC_CONST;
BoxesDisplaySavedProperty* boxes_display_saved_property_dup (const BoxesDisplaySavedProperty* self);
void boxes_display_saved_property_free (BoxesDisplaySavedProperty* self);
void boxes_display_saved_property_copy (const BoxesDisplaySavedProperty* self, BoxesDisplaySavedProperty* dest);
void boxes_display_saved_property_destroy (BoxesDisplaySavedProperty* self);
void boxes_display_sync_config_with_display (BoxesDisplay* self, GObject* display, BoxesDisplaySavedProperty* saved_properties, int saved_properties_length1);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
BoxesDisplayConfig* boxes_display_get_config (BoxesDisplay* self);
void boxes_display_config_load_display_property (BoxesDisplayConfig* self, GObject* display, const gchar* property_name, GValue* default_value);
static void __lambda19_ (Block7Data* _data7_, GParamSpec* pspec);
void boxes_display_config_save_display_property (BoxesDisplayConfig* self, GObject* display, const gchar* property_name);
static void ___lambda19__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
BoxesDisplay* boxes_display_construct (GType object_type);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
gchar* boxes_display_get_uri (BoxesDisplay* self);
gboolean boxes_display_get_can_grab_mouse (BoxesDisplay* self);
void boxes_display_set_can_grab_mouse (BoxesDisplay* self, gboolean value);
gboolean boxes_display_get_mouse_grabbed (BoxesDisplay* self);
void boxes_display_set_mouse_grabbed (BoxesDisplay* self, gboolean value);
gboolean boxes_display_get_need_password (BoxesDisplay* self);
void boxes_display_set_need_password (BoxesDisplay* self, gboolean value);
gboolean boxes_display_get_need_username (BoxesDisplay* self);
void boxes_display_set_need_username (BoxesDisplay* self, gboolean value);
const gchar* boxes_display_get_password (BoxesDisplay* self);
void boxes_display_set_password (BoxesDisplay* self, const gchar* value);
const gchar* boxes_display_get_username (BoxesDisplay* self);
void boxes_display_set_username (BoxesDisplay* self, const gchar* value);
void boxes_display_set_config (BoxesDisplay* self, BoxesDisplayConfig* value);
static GObject * boxes_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _g_object_unref0_ (gpointer var);
static void boxes_display_finalize (GObject* obj);
static void _vala_boxes_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static GtkWidget* boxes_display_real_get_display (BoxesDisplay* self, gint n, GError** error) {
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_get_display'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return NULL;
#line 204 "display.c"
}


GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n, GError** error) {
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->get_display (self, n, error);
#line 213 "display.c"
}


static GdkPixbuf* boxes_display_real_get_pixbuf (BoxesDisplay* self, gint n, GError** error) {
#line 25 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_get_pixbuf'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 25 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return NULL;
#line 222 "display.c"
}


GdkPixbuf* boxes_display_get_pixbuf (BoxesDisplay* self, gint n, GError** error) {
#line 25 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 25 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->get_pixbuf (self, n, error);
#line 231 "display.c"
}


static void boxes_display_real_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable) {
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_set_enable_inputs'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return;
#line 240 "display.c"
}


void boxes_display_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable) {
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_GET_CLASS (self)->set_enable_inputs (self, widget, enable);
#line 249 "display.c"
}


static void boxes_display_real_connect_it (BoxesDisplay* self) {
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_connect_it'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return;
#line 258 "display.c"
}


void boxes_display_connect_it (BoxesDisplay* self) {
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_GET_CLASS (self)->connect_it (self);
#line 267 "display.c"
}


static void boxes_display_real_disconnect_it (BoxesDisplay* self) {
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_disconnect_it'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return;
#line 276 "display.c"
}


void boxes_display_disconnect_it (BoxesDisplay* self) {
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_GET_CLASS (self)->disconnect_it (self);
#line 285 "display.c"
}


static GList* boxes_display_real_get_properties (BoxesDisplay* self, BoxesPropertiesPage page) {
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_get_properties'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return NULL;
#line 294 "display.c"
}


GList* boxes_display_get_properties (BoxesDisplay* self, BoxesPropertiesPage page) {
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->get_properties (self, page);
#line 303 "display.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return self ? g_object_ref (self) : NULL;
#line 310 "display.c"
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return _data7_;
#line 319 "display.c"
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 328 "display.c"
		BoxesDisplay * self;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		self = _data7_->self;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		_g_object_unref0 (_data7_->display);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		_g_object_unref0 (self);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		g_slice_free (Block7Data, _data7_);
#line 338 "display.c"
	}
}


static void __lambda19_ (Block7Data* _data7_, GParamSpec* pspec) {
	BoxesDisplay * self;
	BoxesDisplaySavedProperty* _tmp0_;
	gint _tmp0__length1;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self = _data7_->self;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (pspec != NULL);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = _data7_->saved_properties;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0__length1 = _data7_->saved_properties_length1;
#line 355 "display.c"
	{
		BoxesDisplaySavedProperty* prop_collection = NULL;
		gint prop_collection_length1 = 0;
		gint _prop_collection_size_ = 0;
		gint prop_it = 0;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		prop_collection = _tmp0_;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		prop_collection_length1 = _tmp0__length1;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		for (prop_it = 0; prop_it < _tmp0__length1; prop_it = prop_it + 1) {
#line 367 "display.c"
			BoxesDisplaySavedProperty _tmp1_ = {0};
			BoxesDisplaySavedProperty prop = {0};
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
			boxes_display_saved_property_copy (&prop_collection[prop_it], &_tmp1_);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
			prop = _tmp1_;
#line 374 "display.c"
			{
				GParamSpec* _tmp2_;
				const gchar* _tmp3_;
				BoxesDisplaySavedProperty _tmp4_;
				const gchar* _tmp5_;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				_tmp2_ = pspec;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				_tmp3_ = _tmp2_->name;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				_tmp4_ = prop;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				_tmp5_ = _tmp4_.name;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				if (g_strcmp0 (_tmp3_, _tmp5_) == 0) {
#line 390 "display.c"
					BoxesDisplayConfig* _tmp6_;
					GObject* _tmp7_;
					GParamSpec* _tmp8_;
					const gchar* _tmp9_;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
					_tmp6_ = self->priv->_config;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
					_tmp7_ = _data7_->display;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
					_tmp8_ = pspec;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
					_tmp9_ = _tmp8_->name;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
					boxes_display_config_save_display_property (_tmp6_, _tmp7_, _tmp9_);
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
					boxes_display_saved_property_destroy (&prop);
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
					break;
#line 409 "display.c"
				}
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				boxes_display_saved_property_destroy (&prop);
#line 413 "display.c"
			}
		}
	}
}


static void ___lambda19__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	__lambda19_ (self, pspec);
#line 423 "display.c"
}


void boxes_display_sync_config_with_display (BoxesDisplay* self, GObject* display, BoxesDisplaySavedProperty* saved_properties, int saved_properties_length1) {
	Block7Data* _data7_;
	GObject* _tmp0_;
	GObject* _tmp1_;
	BoxesDisplaySavedProperty* _tmp2_;
	gint _tmp2__length1;
	BoxesDisplayConfig* _tmp3_;
	BoxesDisplaySavedProperty* _tmp4_;
	gint _tmp4__length1;
	GObject* _tmp12_;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (display != NULL);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_data7_ = g_slice_new0 (Block7Data);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_data7_->_ref_count_ = 1;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_data7_->self = g_object_ref (self);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = display;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_data7_->display = _tmp1_;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp2_ = saved_properties;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp2__length1 = saved_properties_length1;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_data7_->saved_properties = _tmp2_;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_data7_->saved_properties_length1 = _tmp2__length1;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp3_ = self->priv->_config;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	if (_tmp3_ == NULL) {
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		block7_data_unref (_data7_);
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		_data7_ = NULL;
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		return;
#line 471 "display.c"
	}
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp4_ = _data7_->saved_properties;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp4__length1 = _data7_->saved_properties_length1;
#line 477 "display.c"
	{
		BoxesDisplaySavedProperty* prop_collection = NULL;
		gint prop_collection_length1 = 0;
		gint _prop_collection_size_ = 0;
		gint prop_it = 0;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		prop_collection = _tmp4_;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		prop_collection_length1 = _tmp4__length1;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		for (prop_it = 0; prop_it < _tmp4__length1; prop_it = prop_it + 1) {
#line 489 "display.c"
			BoxesDisplaySavedProperty _tmp5_ = {0};
			BoxesDisplaySavedProperty prop = {0};
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
			boxes_display_saved_property_copy (&prop_collection[prop_it], &_tmp5_);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
			prop = _tmp5_;
#line 496 "display.c"
			{
				BoxesDisplayConfig* _tmp6_;
				GObject* _tmp7_;
				BoxesDisplaySavedProperty _tmp8_;
				const gchar* _tmp9_;
				BoxesDisplaySavedProperty _tmp10_;
				GValue _tmp11_;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				_tmp6_ = self->priv->_config;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				_tmp7_ = _data7_->display;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				_tmp8_ = prop;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				_tmp9_ = _tmp8_.name;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				_tmp10_ = prop;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				_tmp11_ = _tmp10_.default_value;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				boxes_display_config_load_display_property (_tmp6_, _tmp7_, _tmp9_, &_tmp11_);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
				boxes_display_saved_property_destroy (&prop);
#line 520 "display.c"
			}
		}
	}
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp12_ = _data7_->display;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_signal_connect_data (_tmp12_, "notify", (GCallback) ___lambda19__g_object_notify, block7_data_ref (_data7_), (GClosureNotify) block7_data_unref, 0);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	block7_data_unref (_data7_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_data7_ = NULL;
#line 532 "display.c"
}


BoxesDisplay* boxes_display_construct (GType object_type) {
	BoxesDisplay * self = NULL;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self = (BoxesDisplay*) g_object_new (object_type, NULL);
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return self;
#line 542 "display.c"
}


const gchar* boxes_display_get_protocol (BoxesDisplay* self) {
#line 10 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 10 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->get_protocol (self);
#line 551 "display.c"
}


gchar* boxes_display_get_uri (BoxesDisplay* self) {
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->get_uri (self);
#line 560 "display.c"
}


gboolean boxes_display_get_can_grab_mouse (BoxesDisplay* self) {
	gboolean result;
	gboolean _tmp0_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_can_grab_mouse;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return result;
#line 575 "display.c"
}


void boxes_display_set_can_grab_mouse (BoxesDisplay* self, gboolean value) {
	gboolean _tmp0_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self->priv->_can_grab_mouse = _tmp0_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "can-grab-mouse");
#line 589 "display.c"
}


gboolean boxes_display_get_mouse_grabbed (BoxesDisplay* self) {
	gboolean result;
	gboolean _tmp0_;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_mouse_grabbed;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return result;
#line 604 "display.c"
}


void boxes_display_set_mouse_grabbed (BoxesDisplay* self, gboolean value) {
	gboolean _tmp0_;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self->priv->_mouse_grabbed = _tmp0_;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "mouse-grabbed");
#line 618 "display.c"
}


gboolean boxes_display_get_need_password (BoxesDisplay* self) {
	gboolean result;
	gboolean _tmp0_;
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_need_password;
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return result;
#line 633 "display.c"
}


void boxes_display_set_need_password (BoxesDisplay* self, gboolean value) {
	gboolean _tmp0_;
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self->priv->_need_password = _tmp0_;
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "need-password");
#line 647 "display.c"
}


gboolean boxes_display_get_need_username (BoxesDisplay* self) {
	gboolean result;
	gboolean _tmp0_;
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_need_username;
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return result;
#line 662 "display.c"
}


void boxes_display_set_need_username (BoxesDisplay* self, gboolean value) {
	gboolean _tmp0_;
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self->priv->_need_username = _tmp0_;
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "need-username");
#line 676 "display.c"
}


const gchar* boxes_display_get_password (BoxesDisplay* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_password;
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return result;
#line 691 "display.c"
}


void boxes_display_set_password (BoxesDisplay* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_g_free0 (self->priv->_password);
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self->priv->_password = _tmp1_;
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "password");
#line 710 "display.c"
}


const gchar* boxes_display_get_username (BoxesDisplay* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_username;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return result;
#line 725 "display.c"
}


void boxes_display_set_username (BoxesDisplay* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_g_free0 (self->priv->_username);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self->priv->_username = _tmp1_;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "username");
#line 744 "display.c"
}


BoxesDisplayConfig* boxes_display_get_config (BoxesDisplay* self) {
	BoxesDisplayConfig* result;
	BoxesDisplayConfig* _tmp0_;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_config;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return result;
#line 759 "display.c"
}


void boxes_display_set_config (BoxesDisplay* self, BoxesDisplayConfig* value) {
	BoxesDisplayConfig* _tmp0_;
	BoxesDisplayConfig* _tmp1_;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_g_object_unref0 (self->priv->_config);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self->priv->_config = _tmp1_;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "config");
#line 778 "display.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 785 "display.c"
}


static GObject * boxes_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesDisplay * self;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	parent_class = G_OBJECT_CLASS (boxes_display_parent_class);
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY, BoxesDisplay);
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = g_direct_hash;
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp1_ = g_direct_equal;
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, NULL, _g_object_unref0_);
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_g_hash_table_unref0 (self->displays);
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self->displays = _tmp2_;
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return obj;
#line 814 "display.c"
}


void boxes_display_saved_property_copy (const BoxesDisplaySavedProperty* self, BoxesDisplaySavedProperty* dest) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
	GValue _tmp2_;
	GValue _tmp3_ = {0};
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp0_ = (*self).name;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_g_free0 ((*dest).name);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	(*dest).name = _tmp1_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_tmp2_ = (*self).default_value;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	if (G_IS_VALUE (&_tmp2_)) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		g_value_init (&_tmp3_, G_VALUE_TYPE (&_tmp2_));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		g_value_copy (&_tmp2_, &_tmp3_);
#line 839 "display.c"
	} else {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		_tmp3_ = _tmp2_;
#line 843 "display.c"
	}
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	G_IS_VALUE (&(*dest).default_value) ? (g_value_unset (&(*dest).default_value), NULL) : NULL;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	(*dest).default_value = _tmp3_;
#line 849 "display.c"
}


void boxes_display_saved_property_destroy (BoxesDisplaySavedProperty* self) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_g_free0 ((*self).name);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	G_IS_VALUE (&(*self).default_value) ? (g_value_unset (&(*self).default_value), NULL) : NULL;
#line 858 "display.c"
}


BoxesDisplaySavedProperty* boxes_display_saved_property_dup (const BoxesDisplaySavedProperty* self) {
	BoxesDisplaySavedProperty* dup;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	dup = g_new0 (BoxesDisplaySavedProperty, 1);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	boxes_display_saved_property_copy (self, dup);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	return dup;
#line 870 "display.c"
}


void boxes_display_saved_property_free (BoxesDisplaySavedProperty* self) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	boxes_display_saved_property_destroy (self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_free (self);
#line 879 "display.c"
}


GType boxes_display_saved_property_get_type (void) {
	static volatile gsize boxes_display_saved_property_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_saved_property_type_id__volatile)) {
		GType boxes_display_saved_property_type_id;
		boxes_display_saved_property_type_id = g_boxed_type_register_static ("BoxesDisplaySavedProperty", (GBoxedCopyFunc) boxes_display_saved_property_dup, (GBoxedFreeFunc) boxes_display_saved_property_free);
		g_once_init_leave (&boxes_display_saved_property_type_id__volatile, boxes_display_saved_property_type_id);
	}
	return boxes_display_saved_property_type_id__volatile;
}


static void boxes_display_class_init (BoxesDisplayClass * klass) {
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	boxes_display_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_type_class_add_private (klass, sizeof (BoxesDisplayPrivate));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_display = boxes_display_real_get_display;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_pixbuf = boxes_display_real_get_pixbuf;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->set_enable_inputs = boxes_display_real_set_enable_inputs;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->connect_it = boxes_display_real_connect_it;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->disconnect_it = boxes_display_real_disconnect_it;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_properties = boxes_display_real_get_properties;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_display_get_property;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_display_set_property;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_display_constructor;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_display_finalize;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_PROTOCOL, g_param_spec_string ("protocol", "protocol", "protocol", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_CAN_GRAB_MOUSE, g_param_spec_boolean ("can-grab-mouse", "can-grab-mouse", "can-grab-mouse", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_MOUSE_GRABBED, g_param_spec_boolean ("mouse-grabbed", "mouse-grabbed", "mouse-grabbed", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_NEED_PASSWORD, g_param_spec_boolean ("need-password", "need-password", "need-password", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_NEED_USERNAME, g_param_spec_boolean ("need-username", "need-username", "need-username", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_PASSWORD, g_param_spec_string ("password", "password", "password", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_USERNAME, g_param_spec_string ("username", "username", "username", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_CONFIG, g_param_spec_object ("config", "config", "config", BOXES_TYPE_DISPLAY_CONFIG, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_signal_new ("show", BOXES_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_signal_new ("hide", BOXES_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	g_signal_new ("disconnected", BOXES_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 943 "display.c"
}


static void boxes_display_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	boxes_display_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	iface->get_properties = (GList* (*)(BoxesIPropertiesProvider*, BoxesPropertiesPage)) boxes_display_get_properties;
#line 952 "display.c"
}


static void boxes_display_instance_init (BoxesDisplay * self) {
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self->priv = BOXES_DISPLAY_GET_PRIVATE (self);
#line 959 "display.c"
}


static void boxes_display_finalize (GObject* obj) {
	BoxesDisplay * self;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY, BoxesDisplay);
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_g_free0 (self->priv->_password);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_g_free0 (self->priv->_username);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_g_hash_table_unref0 (self->displays);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	_g_object_unref0 (self->priv->_config);
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	G_OBJECT_CLASS (boxes_display_parent_class)->finalize (obj);
#line 977 "display.c"
}


GType boxes_display_get_type (void) {
	static volatile gsize boxes_display_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDisplayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_display_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDisplay), 0, (GInstanceInitFunc) boxes_display_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_display_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_display_type_id;
		boxes_display_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesDisplay", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (boxes_display_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_display_type_id__volatile, boxes_display_type_id);
	}
	return boxes_display_type_id__volatile;
}


static void _vala_boxes_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY, BoxesDisplay);
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	switch (property_id) {
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_CAN_GRAB_MOUSE:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		g_value_set_boolean (value, boxes_display_get_can_grab_mouse (self));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_MOUSE_GRABBED:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		g_value_set_boolean (value, boxes_display_get_mouse_grabbed (self));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_NEED_PASSWORD:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		g_value_set_boolean (value, boxes_display_get_need_password (self));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_NEED_USERNAME:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		g_value_set_boolean (value, boxes_display_get_need_username (self));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_PASSWORD:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		g_value_set_string (value, boxes_display_get_password (self));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_USERNAME:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		g_value_set_string (value, boxes_display_get_username (self));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_CONFIG:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		g_value_set_object (value, boxes_display_get_config (self));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 1042 "display.c"
		default:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 1048 "display.c"
	}
}


static void _vala_boxes_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY, BoxesDisplay);
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
	switch (property_id) {
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_CAN_GRAB_MOUSE:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		boxes_display_set_can_grab_mouse (self, g_value_get_boolean (value));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_MOUSE_GRABBED:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		boxes_display_set_mouse_grabbed (self, g_value_get_boolean (value));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_NEED_PASSWORD:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		boxes_display_set_need_password (self, g_value_get_boolean (value));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_NEED_USERNAME:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		boxes_display_set_need_username (self, g_value_get_boolean (value));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_PASSWORD:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		boxes_display_set_password (self, g_value_get_string (value));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_USERNAME:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		boxes_display_set_username (self, g_value_get_string (value));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_CONFIG:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		boxes_display_set_config (self, g_value_get_object (value));
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 1100 "display.c"
		default:
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display.vala"
		break;
#line 1106 "display.c"
	}
}



